# GPT-4 Command Executor

GPT-4 Command Executor is a Python application that uses the OpenAI GPT-4 model to generate terminal commands based on user input and execute them locally on the user's computer.

## ⚠️ Warning

Executing commands generated by an AI model may lead to unexpected results and security risks. Always review and approve the commands before allowing them to execute.

## Features

- Interact with OpenAI's GPT-4 model to generate terminal commands
- Execute commands locally using the Python `subprocess` library
- Store API keys securely using environment variables and `python-dotenv`

## Requirements

- Python 3.6 or higher
- An OpenAI API key (register at https://beta.openai.com/signup/)

## Installation
1. Clone the repository
2. Change to the project directory
3. Install the required dependencies using `make install`
4. Set up the '.env' file
5. Install the project as a Python package using `pip install -e .`
6. chmod +x copilot_cli
7. Run the script using `./copilot_cli`
8. Check out examples below
9. Enjoy!

## Example

The script will prompt you for a command request, and then use GPT-4 to generate and execute a potential terminal command based on your input.

Please ensure you understand and accept all potential risks associated with executing AI-generated commands. Always review and approve the commands before executing them to avoid unintended results or security-related issues.

Here's an example of the script in action:

```
    ~/gpt4-command-executor    main *2 +5 !4    ./copilot_cli '?? print working directory'                                              ✔  gpt4-command-executor   system  
Generated command: pwd
Do you want to execute this command? (y/n): y
/home/kacper/gpt4-command-executor
```

```
    ~/gpt4-command-executor    main *2 +5 !4    ./copilot_cli '?? print docker processes, and show these ports'                  ✔  4s   gpt4-command-executor   system  
Generated command: docker ps -a -q --no-trunc | xargs docker port
Do you want to execute this command? (y/n): y
```

```
    ~/gpt4-command-executor    main *2    ./copilot_cli '?? check my version of node.js'                                            INT ✘  gpt4-command-executor   system  
Generated command: node -v
Do you want to execute this command? (y/n): y
v19.8.1
```

## Contributing
Contributions are welcome! Please feel free to submit a Pull Request or create an Issue if you encounter any problems or have suggestions for improvements.

## License
This project is licensed under the MIT License. See the LICENSE file for more information.